#
# Conditional build:
%bcond_without	java		# Java module
%bcond_without	python		# Python 3 module
%bcond_without	bindings	# build bindings (currently only C#/Win32 and Java/Android supported)
# https://github.com/open-eid/libdigidocpp/issues/231
%bcond_with	podofo		# outdated PoDoFo support (disabled in sources)

%if %{without bindings}
%undefine	with_java
%undefine	with_python
%endif

Summary:	Library for creating and validating BDoc and DDoc containers
Summary(pl.UTF-8):	Biblioteka do tworzenia i sprawdzania poprawności kontenerów BDoc i DDoc
Name:		libdigidocpp
Version:	3.16.0
Release:	3
License:	LGPL v2.1+
Group:		Libraries
#Source0Download: https://github.com/open-eid/libdigidocpp/releases
Source0:	https://github.com/open-eid/libdigidocpp/releases/download/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	879590bba8b236b128646871003593cd
Patch0:		%{name}-link.patch
Patch1:		%{name}-python.patch
URL:		https://github.com/open-eid/libdigidocpp
# for tests
BuildRequires:	boost-devel
BuildRequires:	cmake >= 3.16
BuildRequires:	doxygen
BuildRequires:	libstdc++-devel
BuildRequires:	minizip-devel >= 1
BuildRequires:	openssl-devel >= 1.1.1
BuildRequires:	pkgconfig
%{?with_podofo:BuildRequires:	podofo-devel}
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpmbuild(macros) >= 1.734
%if %{with perl} || %{with php} || %{with python}
BuildRequires:	swig
%endif
BuildRequires:	xerces-c-devel
BuildRequires:	xml-security-c-devel
BuildRequires:	xsd >= 4.0
BuildRequires:	xxd
BuildRequires:	zlib-devel
%if %{with python}
BuildRequires:	python3-devel >= 1:3.2
BuildRequires:	swig-python >= 2
%endif
Requires:	opensc
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
libdigidocpp is a C++ library for reading, validating, and creating
BDoc and DDoc containers. These file formats are widespread in Estonia
where they are used for storing legally binding digital signatures.

%description -l pl.UTF-8
libdigidocpp to biblioteka C++ do odczytu, sprawdzania poprawności i
tworzenia kontenerów BDoc i DDoc. Te formaty plików są
rozpowszechnione w Estonii, gdzie służą do przechowywania umocowanych
prawnie podpisów cyfrowych.

%package devel
Summary:	Development files for libdigidocpp library
Summary(pl.UTF-8):	Pliki programistyczne biblioteki libdigidocpp
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	libstdc++-devel

%description devel
This package contains the header files for developing applications
that use libdigidocpp library.

%description devel -l pl.UTF-8
Ten pakiet zawiera pliki nagłówkowe do tworzenia aplikacji
wykorzystujących bibliotekę libdigidocpp.

%package apidocs
Summary:	API documentation for libdigidocpp library
Summary(pl.UTF-8):	Dokumentacja API biblioteki libdigidocpp
Group:		Documentation
BuildArch:	noarch

%description apidocs
API documentation for libdigidocpp library.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki libdigidocpp.

%package -n python3-digidoc
Summary:	Python bindings for libdigidocpp library
Summary(pl.UTF-8):	Wiązania Pythona do biblioteki libdigidocpp
Group:		Development/Languages/Python
Requires:	%{name} = %{version}-%{release}
Provides:	%{name}-python = %{version}-%{release}
Obsoletes:	libdigidocpp-python < 0.3.0-1
Obsoletes:	python-digidoc < 0.3.0-2

%description -n python3-digidoc
Python bindings for libdigidocpp library.

%description -n python3-digidoc -l pl.UTF-8
Wiązania Pythona do biblioteki libdigidocpp.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1

# Remove bundled copy of minizip
%{__rm} -r src/minizip

%build
%cmake -B build \
	-DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} \
	-DPython3_SITELIB=%{py3_sitedir}

%{__make} -C build

%install
rm -rf $RPM_BUILD_ROOT

%{__make} -C build install \
	DESTDIR=$RPM_BUILD_ROOT

%py3_comp $RPM_BUILD_ROOT%{py3_sitedir}
%py3_ocomp $RPM_BUILD_ROOT%{py3_sitedir}

# packaged as %doc
%{__rm} -r $RPM_BUILD_ROOT%{_docdir}/%{name}

# should be as dll not sources
%{__rm} -r $RPM_BUILD_ROOT%{_includedir}/digidocpp_csharp
# should be as jar not sources
%{__rm} -r $RPM_BUILD_ROOT%{_includedir}/ee/ria/libdigidocpp

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS COPYING README.md RELEASE-NOTES.md
%dir %{_sysconfdir}/digidocpp
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/digidocpp/digidocpp.conf
%{_sysconfdir}/digidocpp/schema
%attr(755,root,root) %{_libdir}/libdigidocpp.so.*.*.*
%ghost %attr(755,root,root) %{_libdir}/libdigidocpp.so.1
%attr(755,root,root) %{_bindir}/digidoc-tool
%{_mandir}/man1/digidoc-tool.1*

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libdigidocpp.so
%{_includedir}/digidocpp
%{_pkgconfigdir}/libdigidocpp.pc

%files apidocs
%defattr(644,root,root,755)
%doc build/doc/*

# TODO: csharp, java bindings?
#%attr(755,root,root) %{_libdir}/libdigidoc_csharp.so
#%attr(755,root,root) %{_libdir}/libdigidoc_java.so

%if %{with python}
%files -n python3-digidoc
%defattr(644,root,root,755)
%attr(755,root,root) %{py3_sitedir}/_digidoc_python.so
%{py3_sitedir}/digidoc.py
%{py3_sitedir}/__pycache__/digidoc.cpython-*.py[co]
%endif
%changelog
* Tue Mar 11 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/libdigidocpp.git;a=log;h=master

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> 9817b65
- Release 3 (by relup.sh)

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> 90af484
- use patch -P

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> b79f6e2
- python 3.13 rebuild

* Mon Feb 19 2024 Jakub Bogusz <qboosh@pld-linux.org> 411646c
- removed perl and php packages (never existed in PLD, not supported in cmakefiles)

* Mon Feb 19 2024 Jakub Bogusz <qboosh@pld-linux.org> 1785bb9
- updated to 3.16.0, added python3 binding

* Fri Sep 24 2021 Jan Rękorajski <baggins@pld-linux.org> 542098d
- rebuild with openssl 3.0.0

* Mon Dec 10 2018 Elan Ruusamäe <glen@pld-linux.org> b7bd693
- expand version for ppkgconfig properly

* Mon Dec 10 2018 Elan Ruusamäe <glen@pld-linux.org> de773a4
- up to 3.13.8

* Fri Sep 28 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> f69083f
- missing patch

* Thu Sep 27 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 3cb3995
- up to 3.13.6; podofo not enabled because older podofo is needed

* Fri Sep 14 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 071ab8b
- release 2 (by relup.sh)

* Wed Jun 20 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> b9d8bcd
- use newer rpm macros that skip checking std::__once_callable, std::__once_call

* Sat Nov 25 2017 Jakub Bogusz <qboosh@pld-linux.org> ed0be3f
- updated to 3.13.2
- added link patch (fix missing libpthread linking)

* Mon Sep 18 2017 Elan Ruusamäe <glen@delfi.ee> d6f713b
- BR xxd, pkg-config, boost-devel

* Mon Sep 18 2017 Elan Ruusamäe <glen@pld-linux.org> 6f450f5
- up to 3.12.3, new SONAME: libdigidocpp.so.1

* Sun Feb 22 2015 Elan Ruusamäe <glen@delfi.ee> a38f41b
- up to 3.9.0.1237

* Wed Feb 01 2012 Arkadiusz Miśkiewicz <arekm@maven.pl> 90eeecd
- release 3

* Wed Aug 31 2011 Arkadiusz Miśkiewicz <arekm@maven.pl> 07a9390
- release 2

* Sun Jan 23 2011 Elan Ruusamäe <glen@pld-linux.org> 17b7293
- build without bindings

* Mon Jan 03 2011 Elan Ruusamäe <glen@pld-linux.org> 919f854
- new, based from fc spec, builds without bindings

